RestSessionCatalogBuilder

Struct RestSessionCatalogBuilder 

pub struct RestSessionCatalogBuilder { /* private fields */ }
Builder for an unbound RestSessionCatalog.

Unlike RestCatalogBuilder, the resulting catalog accepts a [SessionContext] with each [SessionCatalog] operation.

Implementations

Source

impl RestSessionCatalogBuilder

pub fn with_client(self, client: Client) -> Self

Configures the catalog with a custom HTTP client.

pub fn with_auth_manager(self, auth_manager: Arc<dyn AuthManager>) -> Self

Injects a custom auth manager, overriding the rest.auth.type configuration.

pub fn with_storage_factory( self, storage_factory: Arc<dyn StorageFactory>, ) -> Self

Set a custom StorageFactory to use for storage operations.

When a StorageFactory is provided, the catalog will use it to build FileIO instances for all storage operations instead of using the default factory.

Arguments
  • storage_factory - The StorageFactory to use for creating storage instances
Example
use iceberg::io::StorageFactory;
use iceberg_catalog_rest::RestSessionCatalogBuilder;
use iceberg_storage_opendal::OpenDalStorageFactory;
use std::sync::Arc;

let catalog = RestSessionCatalogBuilder::default()
    .with_storage_factory(Arc::new(OpenDalStorageFactory::S3 {
        customized_credential_load: None,
    }))
    .load("my_catalog", props)
    .await?;
pub fn with_kms_client_factory( self, kms_client_factory: Arc<dyn KmsClientFactory>, ) -> Self

Set a [KmsClientFactory] to enable table encryption.

When provided, the catalog calls the factory once during load with the catalog properties to create a shared [KeyManagementClient]. That client is then passed to each table’s TableBuilder so tables with encryption.key-id set can construct an EncryptionManager.

Example
use iceberg::encryption::kms::KmsClientFactory;
use iceberg_catalog_rest::RestSessionCatalogBuilder;
use std::sync::Arc;

let catalog = RestSessionCatalogBuilder::default()
    .with_kms_client_factory(Arc::new(MyKmsClientFactory))
    .load("my_catalog", props)
    .await?;
pub fn with_runtime(self, runtime: Runtime) -> Self

Set a custom tokio Runtime to use for spawning async tasks.

When a Runtime is provided, the catalog will propagate it to all tables it creates. Tasks such as scan planning and delete file processing will be spawned on this runtime.

pub fn load( self, name: impl Into<String>, props: HashMap<String, String>, ) -> impl Future<Output = Result<RestSessionCatalog>> + Send

Creates a new session catalog instance.

The server configuration handshake, endpoint negotiation, and authentication sessions are initialized lazily on the first operation.